@@ -1,6 +1,5 @@
-/* Copyright (C) 2005-2019 Free Software Foundation, Inc.
+/* Copyright (C) 2005-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Jakub Jelinek <jakub@redhat.com>, 2005.
 
    The GNU C Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -14,7 +13,7 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #include <errno.h>
 #include <stdbool.h>
@@ -23,6 +22,7 @@
 #include <sys/wait.h>
 #include <tst-stack-align.h>
 #include <unistd.h>
+#include <libc-diag.h>
 
 static int res, fds[2], result;
 static bool test_destructors;
@@ -92,6 +92,8 @@ do_test (void)
   int des_seen = 0, dso_des_seen = 0;
   while ((len = TEMP_FAILURE_RETRY (read (fds[0], &c, 1))) > 0)
     {
+      DIAG_PUSH_NEEDS_COMMENT_CLANG;
+      DIAG_IGNORE_NEEDS_COMMENT_CLANG (3.2, "-Wimplicit-fallthrough");
       switch (c)
         {
         case 'B':
@@ -113,6 +115,7 @@ do_test (void)
           result = 1;
           break;
         }
+      DIAG_POP_NEEDS_COMMENT_CLANG;
     }
 
   close (fds[0]);
