@@ -1,4 +1,4 @@
-/* Conversion from and to ISO 8859-7.
+/* Conversion from and to ISO 8859-4.
    Copyright (C) 1997-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -18,9 +18,9 @@
 
 /* Get the conversion table.  */
 #include <stdint.h>
-#define TABLES <iso8859-7.h>
+#include <iso8859-4.h>
 
-#define CHARSET_NAME	"ISO-8859-7//"
-#define HAS_HOLES	1	/* Not all 256 character are defined.  */
+#define CHARSET_NAME	"ISO-8859-4//"
+#define HAS_HOLES	0	/* All 256 character are defined.  */
 
-#include <8bit-gap.c>
+#include <8bit-generic.c>
