@@ -5,11 +5,11 @@
 
 void
 __error_internal (int status, int errnum, const char *message,
-		  va_list args, unsigned int mode_flags);
+		  va_list args, unsigned int mode_flags) __COLD;
 
 void
 __error_at_line_internal (int status, int errnum, const char *file_name,
 			  unsigned int line_number, const char *message,
-			  va_list args, unsigned int mode_flags);
+			  va_list args, unsigned int mode_flags) __COLD;
 
 #endif
