@@ -1,5 +1,5 @@
 /* Initialize a cthreads mutex structure.
-   Copyright (C) 1995-2019 Free Software Foundation, Inc.
+   Copyright (C) 1995-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #include <lock-intern.h>
 #include <lowlevellock.h>
@@ -22,6 +22,6 @@
 void
 __mutex_init (void *lock)
 {
-  *(int *)lock = LLL_INITIALIZER;
+  *(int *)lock = LLL_LOCK_INITIALIZER;
 }
 libc_hidden_def (__mutex_init)
