@@ -1,7 +1,6 @@
 /* Get priority protocol setting from pthread_mutexattr_t.
-   Copyright (C) 2006-2015 Free Software Foundation, Inc.
+   Copyright (C) 2006-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Jakub Jelinek <jakub@redhat.com>, 2006.
 
    The GNU C Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -15,15 +14,13 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #include <pthreadP.h>
-
+#include <shlib-compat.h>
 
 int
-pthread_mutexattr_getprotocol (attr, protocol)
-     const pthread_mutexattr_t *attr;
-     int *protocol;
+__pthread_mutexattr_getprotocol (const pthread_mutexattr_t *attr, int *protocol)
 {
   const struct pthread_mutexattr *iattr;
 
@@ -34,3 +31,10 @@ pthread_mutexattr_getprotocol (attr, protocol)
 
   return 0;
 }
+versioned_symbol (libc, __pthread_mutexattr_getprotocol,
+		  pthread_mutexattr_getprotocol, GLIBC_2_34);
+
+#if OTHER_SHLIB_COMPAT (libpthread, GLIBC_2_4, GLIBC_2_34)
+compat_symbol (libpthread, __pthread_mutexattr_getprotocol,
+               pthread_mutexattr_getprotocol, GLIBC_2_4);
+#endif
