@@ -1,6 +1,5 @@
-/* Copyright (c) 1998-2015 Free Software Foundation, Inc.
+/* Copyright (c) 1998-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Thorsten Kukuk <kukuk@suse.de>, 1998.
 
    The GNU C Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -14,7 +13,7 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #ifndef _NSCD_H
 #define _NSCD_H	1
@@ -66,7 +65,7 @@ typedef enum
 struct traced_file
 {
   /* Tracks the last modified time of the traced file.  */
-  time_t mtime;
+  __time64_t mtime;
   /* Support multiple registered files per database.  */
   struct traced_file *next;
   int call_res_init;
@@ -108,7 +107,7 @@ init_traced_file(struct traced_file *file, const char *fname, int crinit)
        size_t len = (size_t)(dname - fname);
        if (len > sizeof (file->dname))
 	 abort ();
-       strncpy (file->dname, file->fname, len);
+       memcpy (file->dname, file->fname, len);
        file->dname[len] = '\0';
      }
    /* The basename is the name just after the last forward slash.  */
@@ -364,6 +363,8 @@ extern void gc (struct database_dyn *db);
 /* nscd_setup_thread.c */
 extern int setup_thread (struct database_dyn *db);
 
+/* cachedumper.c */
+extern void nscd_print_cache (const char *name);
 
 /* Special version of TEMP_FAILURE_RETRY for functions returning error
    values.  */
