@@ -1,4 +1,5 @@
-/* Copyright (C) 2001-2023 Free Software Foundation, Inc.
+/* Copyright (C) 2001-2025 Free Software Foundation, Inc.
+   Copyright The GNU Toolchain Authors.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -85,11 +86,11 @@ static int idle_thread_count;
 
 
 /* These are the values used for optimization.  We will probably
-   create a funcion to set these values.  */
+   create a function to set these values.  */
 static struct gaiinit optim =
 {
   20,	/* int gai_threads;	Maximal number of threads.  */
-  64,	/* int gai_num;		Number of expected simultanious requests. */
+  64,	/* int gai_num;		Number of expected simultaneous requests. */
   0,
   0,
   0,
@@ -434,11 +435,15 @@ handle_requests (void *arg)
 
 
 /* Free allocated resources.  */
-libc_freeres_fn (free_res)
+#if !PTHREAD_IN_LIBC
+__attribute__ ((__destructor__)) static
+#endif
+void
+__gai_freemem (void)
 {
   size_t row;
 
-  for (row = 0; row < pool_max_size; ++row)
+  for (row = 0; row < pool_size; ++row)
     free (pool[row]);
 
   free (pool);
