@@ -1,7 +1,6 @@
 /* Convert string representing a number to integer value, using given locale.
-   Copyright (C) 1997-2019 Free Software Foundation, Inc.
+   Copyright (C) 1997-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997.
 
    The GNU C Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -15,13 +14,17 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #define QUAD	1
 
+#include <features.h>
+#undef __GLIBC_USE_C23_STRTOL
+#define __GLIBC_USE_C23_STRTOL 0
 #include <locale.h>
+#include <stdbool.h>
 
 extern long long int ____strtoll_l_internal (const char *, char **, int, int,
-					     locale_t);
+					     bool, locale_t);
 
 #include <strtol_l.c>
