@@ -1,4 +1,4 @@
-/* Copyright (C) 1991-2022 Free Software Foundation, Inc.
+/* Copyright (C) 1991-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -21,5 +21,5 @@
 char *
 strerror (int errnum)
 {
-  return __strerror_l (errnum, __libc_tsd_get (locale_t, LOCALE));
+  return __strerror_l (errnum, __libc_tsd_LOCALE);
 }
