@@ -30,7 +30,7 @@
  */
 /*
  * The original source is from the RPCSRC 4.0 package from Sun Microsystems.
- * The Interface to keyserver protocoll 2, RPC over AF_UNIX and Linux/doors
+ * The Interface to keyserver protocol 2, RPC over AF_UNIX and Linux/doors
  * was added by Thorsten Kukuk <kukuk@suse.de>
  * Since the Linux/doors project was stopped, I doubt that this code will
  * ever be useful <kukuk@suse.de>.
@@ -293,6 +293,15 @@ libc_hidden_nolink_sunrpc (key_get_conv, GLIBC_2_1)
 cryptkeyres *(*__key_encryptsession_pk_LOCAL) (uid_t, char *);
 cryptkeyres *(*__key_decryptsession_pk_LOCAL) (uid_t, char *);
 des_block *(*__key_gendes_LOCAL) (uid_t, char *);
+#ifdef SHARED
+# ifndef EXPORT_RPC_SYMBOLS
+compat_symbol (libc, __key_encryptsession_pk_LOCAL,
+	       __key_encryptsession_pk_LOCAL, GLIBC_2_1);
+compat_symbol (libc, __key_decryptsession_pk_LOCAL,
+	       __key_decryptsession_pk_LOCAL, GLIBC_2_1);
+compat_symbol (libc, __key_gendes_LOCAL, __key_gendes_LOCAL, GLIBC_2_1);
+# endif
+#endif
 
 #ifndef SO_PASSCRED
 static int
@@ -378,11 +387,7 @@ struct  key_call_private {
   pid_t   pid;            /* process-id at moment of creation */
   uid_t   uid;            /* user-id at last authorization */
 };
-#ifdef _RPC_THREAD_SAFE_
 #define key_call_private_main RPC_THREAD_VARIABLE(key_call_private_s)
-#else
-static struct key_call_private *key_call_private_main;
-#endif
 __libc_lock_define_initialized (static, keycall_lock)
 
 /*
@@ -537,7 +542,7 @@ key_call (u_long proc, xdrproc_t xdr_arg, char *arg,
   else if (proc == KEY_GEN && __key_gendes_LOCAL)
     {
       des_block *res;
-      res = (*__key_gendes_LOCAL) (__geteuid (), 0);
+      res = (*__key_gendes_LOCAL) (__geteuid (), NULL);
       *(des_block *) rslt = *res;
       return 1;
     }
@@ -555,7 +560,6 @@ key_call (u_long proc, xdrproc_t xdr_arg, char *arg,
 #endif
 }
 
-#ifdef _RPC_THREAD_SAFE_
 void
 __rpc_thread_key_cleanup (void)
 {
@@ -570,4 +574,3 @@ __rpc_thread_key_cleanup (void)
 		free (kcp);
 	}
 }
-#endif /* _RPC_THREAD_SAFE_ */
