@@ -1,5 +1,5 @@
 /* Utilities functions to name memory mappings.
-   Copyright (C) 2023-2024 Free Software Foundation, Inc.
+   Copyright (C) 2023-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,6 +19,18 @@
 #ifndef __SETVMANAME_H
 #define __SETVMANAME_H
 
+#include <stdbool.h>
+
+/* Set this to small value to not waste memory on systems, which do
+ * not support VMA name. */
+#define ANON_VMA_NAME_MAX_LEN 16
+
+static inline bool
+__is_decorate_maps_enabled (void)
+{
+  return false;
+}
+
 static inline
 void __set_vma_name (void *start, size_t len, const char *name)
 {
