@@ -1,5 +1,5 @@
 /* pthread_attr_getschedparam.  Generic version.
-   Copyright (C) 2002-2024 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -19,7 +19,7 @@
 #include <pthread.h>
 #include <sched.h>
 #include <string.h>
-
+#include <shlib-compat.h>
 #include <pt-internal.h>
 
 int
@@ -34,5 +34,8 @@ __pthread_attr_setschedparam (pthread_attr_t *attr,
 
   return ENOTSUP;
 }
+versioned_symbol (libc, __pthread_attr_setschedparam, pthread_attr_setschedparam, GLIBC_2_21);
 
-weak_alias (__pthread_attr_setschedparam, pthread_attr_setschedparam);
+#if OTHER_SHLIB_COMPAT (libpthread, GLIBC_2_12, GLIBC_2_21)
+compat_symbol (libc, __pthread_attr_setschedparam, pthread_attr_setschedparam, GLIBC_2_12);
+#endif
