@@ -1,5 +1,5 @@
 /* pthread_barrierattr_init.  Generic version.
-   Copyright (C) 2002-2020 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -18,12 +18,19 @@
 
 #include <pthread.h>
 #include <pt-internal.h>
+#include <shlib-compat.h>
 
 int
-pthread_barrierattr_init (pthread_barrierattr_t *attr)
+__pthread_barrierattr_init (pthread_barrierattr_t *attr)
 {
   ASSERT_TYPE_SIZE (pthread_barrierattr_t, __SIZEOF_PTHREAD_BARRIERATTR_T);
 
   *attr = __pthread_default_barrierattr;
   return 0;
 }
+libc_hidden_def (__pthread_barrierattr_init)
+versioned_symbol (libc, __pthread_barrierattr_init, pthread_barrierattr_init, GLIBC_2_42);
+
+#if OTHER_SHLIB_COMPAT (libpthread, GLIBC_2_12, GLIBC_2_42)
+compat_symbol (libpthread, __pthread_barrierattr_init, pthread_barrierattr_init, GLIBC_2_12);
+#endif
