@@ -1,5 +1,5 @@
 /* pthread_rwlockattr_destroy.  Generic version.
-   Copyright (C) 2002-2023 Free Software Foundation, Inc.
+   Copyright (C) 2002-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -18,9 +18,16 @@
 
 #include <pthread.h>
 #include <pt-internal.h>
+#include <shlib-compat.h>
 
 int
-pthread_rwlockattr_destroy (pthread_rwlockattr_t *attr)
+__pthread_rwlockattr_destroy (pthread_rwlockattr_t *attr)
 {
   return 0;
 }
+libc_hidden_def (__pthread_rwlockattr_destroy)
+versioned_symbol (libc, __pthread_rwlockattr_destroy, pthread_rwlockattr_destroy, GLIBC_2_42);
+
+#if OTHER_SHLIB_COMPAT (libpthread, GLIBC_2_12, GLIBC_2_42)
+compat_symbol (libpthread, __pthread_rwlockattr_destroy, pthread_rwlockattr_destroy, GLIBC_2_12);
+#endif
