@@ -1,7 +1,6 @@
 /* Install given floating-point environment.
-   Copyright (C) 1997-2015 Free Software Foundation, Inc.
+   Copyright (C) 1997-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
-   Contributed by Ulrich Drepper <drepper@cygnus.com>, 1997.
 
    The GNU C Library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -15,13 +14,18 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #include <fenv.h>
+#include <fpu_control.h>
 #include <assert.h>
 #include <unistd.h>
 #include <ldsodefs.h>
-#include <dl-procinfo.h>
+
+
+/* All exceptions, including the x86-specific "denormal operand"
+   exception.  */
+#define FE_ALL_EXCEPT_X86 (FE_ALL_EXCEPT | __FE_DENORM)
 
 
 int
@@ -40,22 +44,30 @@ __fesetenv (const fenv_t *envp)
 
   if (envp == FE_DFL_ENV)
     {
-      temp.__control_word |= FE_ALL_EXCEPT;
+      temp.__control_word |= FE_ALL_EXCEPT_X86;
       temp.__control_word &= ~FE_TOWARDZERO;
-      temp.__status_word &= ~FE_ALL_EXCEPT;
+      temp.__control_word |= _FPU_EXTENDED;
+      temp.__status_word &= ~FE_ALL_EXCEPT_X86;
     }
   else if (envp == FE_NOMASK_ENV)
     {
       temp.__control_word &= ~(FE_ALL_EXCEPT | FE_TOWARDZERO);
-      temp.__status_word &= ~FE_ALL_EXCEPT;
+      /* Keep the "denormal operand" exception masked.  */
+      temp.__control_word |= __FE_DENORM;
+      temp.__control_word |= _FPU_EXTENDED;
+      temp.__status_word &= ~FE_ALL_EXCEPT_X86;
     }
   else
     {
-      temp.__control_word &= ~(FE_ALL_EXCEPT | FE_TOWARDZERO);
+      temp.__control_word &= ~(FE_ALL_EXCEPT_X86
+			       | FE_TOWARDZERO
+			       | _FPU_EXTENDED);
       temp.__control_word |= (envp->__control_word
-			      & (FE_ALL_EXCEPT | FE_TOWARDZERO));
-      temp.__status_word &= ~FE_ALL_EXCEPT;
-      temp.__status_word |= envp->__status_word & FE_ALL_EXCEPT;
+			      & (FE_ALL_EXCEPT_X86
+				 | FE_TOWARDZERO
+				 | _FPU_EXTENDED));
+      temp.__status_word &= ~FE_ALL_EXCEPT_X86;
+      temp.__status_word |= envp->__status_word & FE_ALL_EXCEPT_X86;
     }
   temp.__eip = 0;
   temp.__cs_selector = 0;
@@ -65,26 +77,36 @@ __fesetenv (const fenv_t *envp)
 
   __asm__ ("fldenv %0" : : "m" (temp));
 
-  if ((GLRO(dl_hwcap) & HWCAP_I386_XMM) != 0)
+  if (CPU_FEATURE_USABLE (SSE))
     {
       unsigned int mxcsr;
       __asm__ ("stmxcsr %0" : "=m" (mxcsr));
 
       if (envp == FE_DFL_ENV)
 	{
+	  /* Clear SSE exceptions.  */
+	  mxcsr &= ~FE_ALL_EXCEPT_X86;
 	  /* Set mask for SSE MXCSR.  */
-	  mxcsr |= (FE_ALL_EXCEPT << 7);
+	  mxcsr |= (FE_ALL_EXCEPT_X86 << 7);
 	  /* Set rounding to FE_TONEAREST.  */
 	  mxcsr &= ~0x6000;
 	  mxcsr |= (FE_TONEAREST << 3);
+	  /* Clear the FZ and DAZ bits.  */
+	  mxcsr &= ~0x8040;
 	}
       else if (envp == FE_NOMASK_ENV)
 	{
+	  /* Clear SSE exceptions.  */
+	  mxcsr &= ~FE_ALL_EXCEPT_X86;
 	  /* Do not mask exceptions.  */
 	  mxcsr &= ~(FE_ALL_EXCEPT << 7);
+	  /* Keep the "denormal operand" exception masked.  */
+	  mxcsr |= (__FE_DENORM << 7);
 	  /* Set rounding to FE_TONEAREST.  */
 	  mxcsr &= ~0x6000;
 	  mxcsr |= (FE_TONEAREST << 3);
+	  /* Clear the FZ and DAZ bits.  */
+	  mxcsr &= ~0x8040;
 	}
       else
 	mxcsr = envp->__eip;
