@@ -1,5 +1,5 @@
 /* Test totalorderl and totalordermagl for ldbl-96.
-   Copyright (C) 2016-2022 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -46,9 +46,9 @@ do_test (void)
 	SET_LDOUBLE_WORDS (ldy, 0x7fff,
 			   (tests[i] >> 32) | 0x80000000,
 			   tests[i] & 0xffffffffULL);
-	SET_LDOUBLE_WORDS (ldnx, 0xffff,
+	SET_LDOUBLE_WORDS (ldnx, -1,
 			   tests[i] >> 32, tests[i] & 0xffffffffULL);
-	SET_LDOUBLE_WORDS (ldny, 0xffff,
+	SET_LDOUBLE_WORDS (ldny, -1,
 			   (tests[i] >> 32) | 0x80000000,
 			   tests[i] & 0xffffffffULL);
 	bool to1 = totalorderl (&ldx, &ldy);
