@@ -1,5 +1,5 @@
 /* Make a link between file names relative to open directories.  Hurd version.
-   Copyright (C) 2006-2021 Free Software Foundation, Inc.
+   Copyright (C) 2006-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -23,18 +23,17 @@
 #include <hurd.h>
 #include <hurd/fd.h>
 
+#include <linkat_common.h>
 
 /* Make a link to FROM relative to FROMFD called TO relative to TOFD.  */
 int
-linkat (int fromfd, const char *from, int tofd, const char *to, int flags)
+__linkat_common (int fromfd, const char *from, int tofd, const char *to, int at_flags, int flags)
 {
   error_t err;
   file_t oldfile, linknode, todir;
   char *toname;
 
-  /* POSIX says linkat doesn't follow symlinks by default, so pass
-     O_NOLINK.  That can be overridden by AT_SYMLINK_FOLLOW in FLAGS.  */
-  oldfile = __file_name_lookup_at (fromfd, flags, from, O_NOLINK, 0);
+  oldfile = __file_name_lookup_at (fromfd, at_flags, from, flags, 0);
   if (oldfile == MACH_PORT_NULL)
     return -1;
 
@@ -49,7 +48,11 @@ linkat (int fromfd, const char *from, int tofd, const char *to, int flags)
   todir = __file_name_split_at (tofd, to, &toname);
   if (todir != MACH_PORT_NULL)
     {
-      err = __dir_link (todir, linknode, toname, 1);
+      if (! *toname)
+	/* Can't link to the existing directory itself.  */
+	err = ENOTDIR;
+      else
+	err = __dir_link (todir, linknode, toname, 1);
       __mach_port_deallocate (__mach_task_self (), todir);
     }
   __mach_port_deallocate (__mach_task_self (), linknode);
@@ -60,3 +63,12 @@ linkat (int fromfd, const char *from, int tofd, const char *to, int flags)
     return __hurd_fail (err);
   return 0;
 }
+
+int
+__linkat (int fromfd, const char *from, int tofd, const char *to, int at_flags)
+{
+  /* POSIX says linkat doesn't follow symlinks by default, so pass
+     O_NOLINK.  That can be overridden by AT_SYMLINK_FOLLOW in FLAGS.  */
+  return __linkat_common (fromfd, from, tofd, to, at_flags, O_NOLINK);
+}
+weak_alias (__linkat, linkat)
