@@ -1,5 +1,5 @@
 /* Create a symbolic link named relative to an open directory.  Hurd version.
-   Copyright (C) 1991-2014 Free Software Foundation, Inc.
+   Copyright (C) 1991-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with the GNU C Library; if not, see
-   <http://www.gnu.org/licenses/>.  */
+   <https://www.gnu.org/licenses/>.  */
 
 #include <errno.h>
 #include <fcntl.h>
@@ -28,10 +28,7 @@
 
 /* Make a link to FROM called TO relative to FD.  */
 int
-symlinkat (from, fd, to)
-     const char *from;
-     int fd;
-     const char *to;
+__symlinkat (const char *from, int fd, const char *to)
 {
   error_t err;
   file_t dir, node;
@@ -48,8 +45,12 @@ symlinkat (from, fd, to)
   if (dir == MACH_PORT_NULL)
     return -1;
 
-  /* Create a new, unlinked node in the target directory.  */
-  err = __dir_mkfile (dir, O_WRITE, 0777 & ~_hurd_umask, &node);
+  if (! *name)
+    /* Can't link to the existing directory itself.  */
+    err = EEXIST;
+  else
+    /* Create a new, unlinked node in the target directory.  */
+    err = __dir_mkfile (dir, O_WRITE, 0777 & ~_hurd_umask, &node);
 
   if (! err)
     {
@@ -73,3 +74,5 @@ symlinkat (from, fd, to)
     return __hurd_fail (err);
   return 0;
 }
+
+weak_alias (__symlinkat, symlinkat)
