@@ -1,5 +1,5 @@
 /* Pthread mutex tunable parameters.
-   Copyright (C) 2018-2023 Free Software Foundation, Inc.
+   Copyright (C) 2018-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -20,7 +20,6 @@
 
 #include <adaptive_spin_count.h>
 
-#if HAVE_TUNABLES
 struct mutex_config
 {
   int spin_count;
@@ -30,12 +29,5 @@ extern struct mutex_config __mutex_aconf;
 libc_hidden_proto (__mutex_aconf)
 
 extern void __pthread_tunables_init (void) attribute_hidden;
-#else
-static inline void
-__pthread_tunables_init (void)
-{
-  /* No tunables to initialize.  */
-}
-#endif
 
 #endif
