@@ -1,5 +1,5 @@
 /* Test readdir64 compatibility symbol.
-   Copyright (C) 2018-2022 Free Software Foundation, Inc.
+   Copyright (C) 2018-2025 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -37,12 +37,15 @@ struct __old_dirent64
 
 typedef struct __old_dirent64 *(*compat_readdir64_type) (DIR *);
 
+#if TEST_COMPAT (libc, GLIBC_2_1, GLIBC_2_2)
 struct __old_dirent64 *compat_readdir64 (DIR *);
 compat_symbol_reference (libc, compat_readdir64, readdir64, GLIBC_2_1);
+#endif
 
 static int
 do_test (void)
 {
+#if TEST_COMPAT (libc, GLIBC_2_1, GLIBC_2_2)
   /* Directory stream using the non-compat readdir64 symbol.  The test
      checks against this.  */
   DIR *dir_reference = opendir (".");
@@ -104,6 +107,7 @@ do_test (void)
 
   TEST_COMPARE (closedir (dir_test), 0);
   TEST_COMPARE (closedir (dir_reference), 0);
+#endif
   return 0;
 }
 
